@@ -15,7 +15,9 @@ validateResult <- function(x, call = parent.frame()) {
 
 validateDecimals <- function(result, decimals) {
   nm_type <- omopgenerics::estimateTypeChoices()
+  nm_type <- nm_type[!nm_type %in% c("logical", "date")]
   nm_name <- result[["estimate_name"]] |> unique()
+  nm_name <- nm_name[!nm_name %in% c("logical", "date")]
   errorMesssage <- "`decimals` must be named integerish vector. Names refere to estimate_type or estimate_name values."
 
   if (is.null(decimals)) {
@@ -27,7 +29,19 @@ validateDecimals <- function(result, decimals) {
     cli::cli_abort(errorMesssage)
   } else if (!all(names(decimals) %in% c(nm_type, nm_name))) { # not correctly named
     conflict_nms <- names(decimals)[!names(decimals) %in% c(nm_type, nm_name)]
-    cli::cli_abort(paste0(paste0(conflict_nms, collapse = ", "), " do not correspont to estimate_type or estimate_name values."))
+    if ("date" %in% conflict_nms) {
+      cli::cli_warn("`date` will not be formatted.")
+      conflict_nms <- conflict_nms[!conflict_nms %in% "date"]
+      decimals <- decimals[!names(decimals) %in% "date"]
+    }
+    if ("logical" %in% conflict_nms) {
+      cli::cli_warn("`logical` will not be formatted.")
+      conflict_nms <- conflict_nms[!conflict_nms %in% "logical"]
+      decimals <- decimals[!names(decimals) %in% "logical"]
+    }
+    if (length(conflict_nms) > 0) {
+      cli::cli_abort(paste0(paste0(conflict_nms, collapse = ", "), " do not correspond to estimate_type or estimate_name values."))
+    }
   } else if (length(decimals) == 1 & is.null(names(decimals))) { # same number to all
     decimals <- rep(decimals, length(nm_type))
     names(decimals) <- nm_type
