@@ -252,7 +252,7 @@ test_that("formatEstimateValue", {
                                      bigMark = "%"))
     expect_error(formatEstimateValue(result,
                                      decimals = c(count = 1, lala = 0)),
-                 "lala do not correspont to estimate_type or estimate_name values.")
+                 "lala do not correspond to estimate_type or estimate_name values.")
     expect_error(formatEstimateValue(result,
                                      decimals = 1,
                                      decimalMark = NULL,
@@ -261,3 +261,61 @@ test_that("formatEstimateValue", {
 
 })
 
+test_that("formatEstimateValue, dates", {
+  result <- dplyr::tibble(
+    "result_id" = integer(1),
+    "cdm_name" = "mock",
+    "result_type" = "mock_summarised_result",
+    "package_name" = "visOmopResults",
+    "package_version" = utils::packageVersion("visOmopResults") |>
+      as.character(),
+    "group_name" = "cohort_name",
+    "group_level" = c(rep("cohort1", 9), rep("cohort2", 9)),
+    "strata_name" = rep(c(
+      "overall", rep("age_group &&& sex", 4), rep("sex", 2), rep("age_group", 2)
+    ), 2),
+    "strata_level" = rep(c(
+      "overall", "<40 &&& Male", ">=40 &&& Male", "<40 &&& Female",
+      ">=40 &&& Female", "Male", "Female", "<40", ">=40"
+    ), 2),
+    "variable_name" = "number subjects",
+    "variable_level" = NA_character_,
+    "estimate_name" = "count",
+    "estimate_type" = "integer",
+    "estimate_value" = round(10000000*stats::runif(18)) |> as.character(),
+    "additional_name" = "overall",
+    "additional_level" = "overall"
+  ) |>
+    dplyr::union_all(
+      dplyr::tibble(
+        "result_id" = integer(1),
+        "cdm_name" = "mock",
+        "result_type" = "mock_summarised_result",
+        "package_name" = "visOmopResults",
+        "package_version" = utils::packageVersion("visOmopResults") |>
+          as.character(),
+        "group_name" = "cohort_name",
+        "group_level" = c(rep("cohort1", 9), rep("cohort2", 9)),
+        "strata_name" = rep(c(
+          "overall", rep("age_group &&& sex", 4), rep("sex", 2), rep("age_group", 2)
+        ), 2),
+        "strata_level" = rep(c(
+          "overall", "<40 &&& Male", ">=40 &&& Male", "<40 &&& Female",
+          ">=40 &&& Female", "Male", "Female", "<40", ">=40"
+        ), 2),
+        "variable_name" = "start date",
+        "variable_level" = NA_character_,
+        "estimate_name" = "date",
+        "estimate_type" = "date",
+        "estimate_value" = as.Date("2020-10-01") |> as.character(),
+        "additional_name" = "overall",
+        "additional_level" = "overall"
+      )
+    ) |>
+    omopgenerics::newSummarisedResult()
+  expect_no_error(result_out <- formatEstimateValue(result, decimals = 0))
+  expect_true(class(as.Date(result_out |> dplyr::filter(estimate_type == "date") |> dplyr::pull(estimate_value))) == "Date")
+
+  expect_warning(result_out <- formatEstimateValue(result, decimals = c(date = 1)))
+  expect_true(class(as.Date(result_out |> dplyr::filter(estimate_type == "date") |> dplyr::pull(estimate_value))) == "Date")
+})
